@@ -58,11 +58,11 @@ def parse_lookup_key(lookup_key):
 
     # Parse the list of keys
     if isinstance(lookup_key, str):
-        keys = lookup_key.split('.')
+        keys = lookup_key.split(".")
     elif isinstance(lookup_key, list):
         keys = lookup_key
     else:
-        raise TypeError('lookup must be string or list')
+        raise TypeError("lookup must be string or list")
 
     return keys
 
@@ -134,3 +134,16 @@ def dict_set(source, key, value):
         else:
             parent = parent.setdefault(key, {})
     parent[keys[-1]] = value
+
+
+def dict_merge(dest, source):
+    """Merges source into dest.
+
+    It does not merge arrays of dicts.
+    """
+    for key in source:
+        if key in dest:
+            if isinstance(dest[key], dict) and isinstance(source[key], dict):
+                dict_merge(dest[key], source[key])
+        else:
+            dest[key] = source[key]
